@@ -26,6 +26,12 @@ static void on_connect_wrapper(struct mosquitto *mosq, void *userdata, int rc)
 	m->on_connect(rc);
 }
 
+static void on_connect_with_flags_wrapper(struct mosquitto *mosq, void *userdata, int rc, int flags)
+{
+	class mosquittopp *m = (class mosquittopp *)userdata;
+	m->on_connect_with_flags(rc, flags);
+}
+
 static void on_disconnect_wrapper(struct mosquitto *mosq, void *userdata, int rc)
 {
 	class mosquittopp *m = (class mosquittopp *)userdata;
@@ -106,10 +112,64 @@ int topic_matches_sub(const char *sub, const char *topic, bool *result)
 	return mosquitto_topic_matches_sub(sub, topic, result);
 }
 
+int validate_utf8(const char *str, int len)
+{
+	return mosquitto_validate_utf8(str, len);
+}
+
+int subscribe_simple(
+		struct mosquitto_message **messages,
+		int msg_count,
+		bool retained,
+		const char *topic,
+		int qos,
+		const char *host,
+		int port,
+		const char *client_id,
+		int keepalive,
+		bool clean_session,
+		const char *username,
+		const char *password,
+		const struct libmosquitto_will *will,
+		const struct libmosquitto_tls *tls)
+{
+	return mosquitto_subscribe_simple(
+			messages, msg_count, retained,
+			topic, qos,
+			host, port, client_id, keepalive, clean_session,
+			username, password,
+			will, tls);
+}
+
+mosqpp_EXPORT int subscribe_callback(
+		int (*callback)(struct mosquitto *, void *, const struct mosquitto_message *),
+		void *userdata,
+		const char *topic,
+		int qos,
+		const char *host,
+		int port,
+		const char *client_id,
+		int keepalive,
+		bool clean_session,
+		const char *username,
+		const char *password,
+		const struct libmosquitto_will *will,
+		const struct libmosquitto_tls *tls)
+{
+	return mosquitto_subscribe_callback(
+			callback, userdata,
+			topic, qos,
+			host, port, client_id, keepalive, clean_session,
+			username, password,
+			will, tls);
+}
+
+
 mosquittopp::mosquittopp(const char *id, bool clean_session)
 {
 	m_mosq = mosquitto_new(id, clean_session, this);
 	mosquitto_connect_callback_set(m_mosq, on_connect_wrapper);
+	mosquitto_connect_with_flags_callback_set(m_mosq, on_connect_with_flags_wrapper);
 	mosquitto_disconnect_callback_set(m_mosq, on_disconnect_wrapper);
 	mosquitto_publish_callback_set(m_mosq, on_publish_wrapper);
 	mosquitto_message_callback_set(m_mosq, on_message_wrapper);
@@ -129,6 +189,7 @@ int mosquittopp::reinitialise(const char *id, bool clean_session)
 	rc = mosquitto_reinitialise(m_mosq, id, clean_session, this);
 	if(rc == MOSQ_ERR_SUCCESS){
 		mosquitto_connect_callback_set(m_mosq, on_connect_wrapper);
+		mosquitto_connect_with_flags_callback_set(m_mosq, on_connect_with_flags_wrapper);
 		mosquitto_disconnect_callback_set(m_mosq, on_disconnect_wrapper);
 		mosquitto_publish_callback_set(m_mosq, on_publish_wrapper);
 		mosquitto_message_callback_set(m_mosq, on_message_wrapper);
