@@ -424,6 +424,10 @@ int socks5__read(struct mosquitto *mosq)
 			/* Auth passed */
 			packet__cleanup(&mosq->in_packet);
 			mosq->state = mosq_cs_new;
+			if(mosq->socks5_host){
+				int rc = net__socket_connect_step3(mosq, mosq->host);
+				if(rc) return rc;
+			}
 			return send__connect(mosq, mosq->keepalive, mosq->clean_session);
 		}else{
 			i = mosq->in_packet.payload[1];
