@@ -14,6 +14,8 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
+#include "config.h"
+
 #ifdef __APPLE__
 #include <mach/mach.h>
 #include <mach/mach_time.h>
@@ -30,33 +32,10 @@ Contributors:
 #include "mosquitto.h"
 #include "time_mosq.h"
 
-#ifdef WIN32
-static bool tick64 = false;
-
-void _windows_time_version_check(void)
-{
-	OSVERSIONINFO vi;
-
-	tick64 = false;
-
-	memset(&vi, 0, sizeof(OSVERSIONINFO));
-	vi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
-	if(GetVersionEx(&vi)){
-		if(vi.dwMajorVersion > 5){
-			tick64 = true;
-		}
-	}
-}
-#endif
-
 time_t mosquitto_time(void)
 {
 #ifdef WIN32
-	if(tick64){
-		return GetTickCount64()/1000;
-	}else{
-		return GetTickCount()/1000; /* FIXME - need to deal with overflow. */
-	}
+	return GetTickCount64()/1000;
 #elif _POSIX_TIMERS>0 && defined(_POSIX_MONOTONIC_CLOCK)
 	struct timespec tp;
 
