@@ -14,8 +14,8 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
-#ifndef _TIME_MOSQ_H_
-#define _TIME_MOSQ_H_
+#ifndef TIME_MOSQ_H
+#define TIME_MOSQ_H
 
 time_t mosquitto_time(void);
 
