@@ -14,8 +14,8 @@ Contributors:
    Roger Light - initial implementation and documentation.
 */
 
-#ifndef _TLS_MOSQ_H_
-#define _TLS_MOSQ_H_
+#ifndef TLS_MOSQ_H
+#define TLS_MOSQ_H
 
 #ifdef WITH_TLS
 #  define SSL_DATA_PENDING(A) ((A)->ssl && SSL_pending((A)->ssl))
@@ -26,16 +26,9 @@ Contributors:
 #ifdef WITH_TLS
 
 #include <openssl/ssl.h>
-#ifdef WITH_TLS_PSK
-#  if OPENSSL_VERSION_NUMBER >= 0x10000000
-#    define REAL_WITH_TLS_PSK
-#  else
-#    warning "TLS-PSK not supported, openssl too old."
-#  endif
-#endif
 
-int _mosquitto_server_certificate_verify(int preverify_ok, X509_STORE_CTX *ctx);
-int _mosquitto_verify_certificate_hostname(X509 *cert, const char *hostname);
+int mosquitto__server_certificate_verify(int preverify_ok, X509_STORE_CTX *ctx);
+int mosquitto__verify_certificate_hostname(X509 *cert, const char *hostname);
 
 #endif /* WITH_TLS */
 
