@@ -16,6 +16,7 @@ Contributors:
 
 #include "config.h"
 
+#include <ctype.h>
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,11 +47,32 @@ Contributors:
 #include "util_mosq.h"
 #include "mqtt3_protocol.h"
 
-int strcasecmp_p(const void *p1, const void *p2)
-{
-	return strcasecmp(*(const char **)p1, *(const char **)p2);
-}
 
+int scmp_p(const void *p1, const void *p2)
+{
+	const char *s1 = *(const char **)p1;
+	const char *s2 = *(const char **)p2;
+	int result;
+
+	while(s1[0] && s2[0]){
+		/* Sort by case insensitive part first */
+		result = toupper(s1[0]) - toupper(s2[0]);
+		if(result == 0){
+			/* Case insensitive part matched, now distinguish between case */
+			result = s1[0] - s2[0];
+			if(result != 0){
+				return result;
+			}
+		}else{
+			/* Return case insensitive match fail */
+			return result;
+		}
+		s1++;
+		s2++;
+	}
+
+	return s1[0] - s2[0];
+}
 
 #ifdef WIN32
 int config__get_dir_files(const char *include_dir, char ***files, int *file_count)
@@ -102,6 +124,7 @@ int config__get_dir_files(const char *include_dir, char ***files, int *file_coun
 
 	FindClose(fh);
 
+	qsort(l_files, l_file_count, sizeof(char *), scmp_p);
 	*files = l_files;
 	*file_count = l_file_count;
 
@@ -111,6 +134,7 @@ int config__get_dir_files(const char *include_dir, char ***files, int *file_coun
 
 
 #ifndef WIN32
+
 int config__get_dir_files(const char *include_dir, char ***files, int *file_count)
 {
 	char **l_files = NULL;
@@ -160,6 +184,7 @@ int config__get_dir_files(const char *include_dir, char ***files, int *file_coun
 	}
 	closedir(dh);
 
+	qsort(l_files, l_file_count, sizeof(char *), scmp_p);
 	*files = l_files;
 	*file_count = l_file_count;
 
