@@ -90,6 +90,15 @@ int handle__connack(struct mosquitto_db *db, struct mosquitto *context)
 						}
 					}
 				}
+				for(i=0; i<context->bridge->topic_count; i++){
+					if(context->bridge->topics[i].direction == bd_out || context->bridge->topics[i].direction == bd_both){
+						log__printf(NULL, MOSQ_LOG_DEBUG, "Bridge %s doing local SUBSCRIBE on topic %s", context->id, context->bridge->topics[i].local_topic);
+						if(sub__add(db, context, context->bridge->topics[i].local_topic, context->bridge->topics[i].qos, &db->subs)) return 1;
+						sub__retain_queue(db, context,
+								context->bridge->topics[i].local_topic,
+								context->bridge->topics[i].qos);
+					}
+				}
 			}
 			context->state = mosq_cs_connected;
 			return MOSQ_ERR_SUCCESS;
