@@ -12,21 +12,21 @@ import mosq_test
 
 rc = 1
 keepalive = 10
-connect_packet = mosq_test.gen_connect("", keepalive=keepalive)
+connect_packet = mosq_test.gen_connect("", keepalive=keepalive, proto_ver=3)
 connack_packet = mosq_test.gen_connack(rc=2)
 
-cmd = ['../../src/mosquitto', '-p', '1888']
-broker = mosq_test.start_broker(filename=os.path.basename(__file__), cmd=cmd)
+port = mosq_test.get_port()
+broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
-    sock = mosq_test.do_client_connect(connect_packet, connack_packet)
+    sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port)
     sock.close()
     rc = 0
 finally:
     broker.terminate()
     broker.wait()
+    (stdo, stde) = broker.communicate()
     if rc:
-        (stdo, stde) = broker.communicate()
         print(stde)
 
 exit(rc)
