@@ -26,13 +26,11 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, timeout=20, port=port)
-    sock.send(subscribe_packet)
 
-    if mosq_test.expect_packet(sock, "suback", suback_packet):
-        sock.send(publish_packet)
+    mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
+    mosq_test.do_send_receive(sock, publish_packet, publish_packet, "publish")
 
-        if mosq_test.expect_packet(sock, "publish", publish_packet):
-            rc = 0
+    rc = 0
 
     sock.close()
 finally:
