@@ -32,15 +32,13 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, timeout=20, port=port)
-    sock.send(subscribe_packet)
 
-    if mosq_test.expect_packet(sock, "suback", suback_packet):
-        sock.send(publish_packet)
+    mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
 
-        if mosq_test.expect_packet(sock, "puback", puback_packet):
+    mosq_test.do_send_receive(sock, publish_packet, puback_packet, "puback")
 
-            if mosq_test.expect_packet(sock, "publish2", publish_packet2):
-                rc = 0
+    if mosq_test.expect_packet(sock, "publish2", publish_packet2):
+        rc = 0
 
     sock.close()
 finally:
