@@ -20,10 +20,10 @@ publish_packet = mosq_test.gen_publish("qos1/disconnect/test", qos=1, mid=mid, p
 puback_packet = mosq_test.gen_puback(mid)
 
 sock = mosq_test.do_client_connect(connect_packet, connack_packet, connack_error="helper connack", port=port)
-sock.send(publish_packet)
 
-if mosq_test.expect_packet(sock, "helper puback", puback_packet):
-    rc = 0
+mosq_test.do_send_receive(sock, publish_packet, puback_packet, "helper puback")
+
+rc = 0
 
 sock.close()
 
