@@ -36,30 +36,29 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack1_packet, port=port)
-    sock.send(subscribe_packet)
 
-    if mosq_test.expect_packet(sock, "suback", suback_packet):
-        pub = subprocess.Popen(['./03-publish-b2c-disconnect-qos1-helper.py', str(port)], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        pub.wait()
-        (stdo, stde) = pub.communicate()
-        # Should have now received a publish command
+    mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
 
-        if mosq_test.expect_packet(sock, "publish", publish_packet):
-            # Send our outgoing message. When we disconnect the broker
-            # should get rid of it and assume we're going to retry.
-            sock.send(publish2_packet)
-            sock.close()
+    pub = subprocess.Popen(['./03-publish-b2c-disconnect-qos1-helper.py', str(port)], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    pub.wait()
+    (stdo, stde) = pub.communicate()
+    # Should have now received a publish command
 
-            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            sock.settimeout(60) # 60 seconds timeout is much longer than 5 seconds message retry.
-            sock.connect(("localhost", port))
-            sock.send(connect_packet)
+    if mosq_test.expect_packet(sock, "publish", publish_packet):
+        # Send our outgoing message. When we disconnect the broker
+        # should get rid of it and assume we're going to retry.
+        sock.send(publish2_packet)
+        sock.close()
 
-            if mosq_test.expect_packet(sock, "connack", connack2_packet):
+        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        sock.settimeout(60) # 60 seconds timeout is much longer than 5 seconds message retry.
+        sock.connect(("localhost", port))
 
-                if mosq_test.expect_packet(sock, "dup publish", publish_dup_packet):
-                    sock.send(puback_packet)
-                    rc = 0
+        mosq_test.do_send_receive(sock, connect_packet, connack2_packet, "connack")
+
+        if mosq_test.expect_packet(sock, "dup publish", publish_dup_packet):
+            sock.send(puback_packet)
+            rc = 0
 
     sock.close()
 finally:
