@@ -36,34 +36,33 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack1_packet, port=port)
-    sock.send(subscribe_packet)
 
-    if mosq_test.expect_packet(sock, "suback", suback_packet):
-        pub = subprocess.Popen(['./03-publish-b2c-disconnect-qos2-helper.py', str(port)], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        hrc = pub.wait()
-        (stdo, stde) = pub.communicate()
-        if hrc:
-            exit(hrc)
-        # Should have now received a publish command
+    mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
+
+    pub = subprocess.Popen(['./03-publish-b2c-disconnect-qos2-helper.py', str(port)], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    hrc = pub.wait()
+    (stdo, stde) = pub.communicate()
+    if hrc:
+        exit(hrc)
+    # Should have now received a publish command
+
+    if mosq_test.expect_packet(sock, "publish", publish_packet):
+        # Send our outgoing message. When we disconnect the broker
+        # should get rid of it and assume we're going to retry.
+        sock.send(publish2_packet)
+        sock.close()
+
+        sock = mosq_test.do_client_connect(connect_packet, connack2_packet, port=port)
+        if mosq_test.expect_packet(sock, "dup publish", publish_dup_packet):
+            mosq_test.do_send_receive(sock, pubrec_packet, pubrel_packet, "pubrel")
 
-        if mosq_test.expect_packet(sock, "publish", publish_packet):
-            # Send our outgoing message. When we disconnect the broker
-            # should get rid of it and assume we're going to retry.
-            sock.send(publish2_packet)
             sock.close()
 
             sock = mosq_test.do_client_connect(connect_packet, connack2_packet, port=port)
-            if mosq_test.expect_packet(sock, "dup publish", publish_dup_packet):
-                sock.send(pubrec_packet)
-
-                if mosq_test.expect_packet(sock, "pubrel", pubrel_packet):
-                    sock.close()
-
-                    sock = mosq_test.do_client_connect(connect_packet, connack2_packet, port=port)
-                    if mosq_test.expect_packet(sock, "dup pubrel", pubrel_packet):
-                        sock.send(pubcomp_packet)
-                        rc = 0
-                    sock.close()
+            if mosq_test.expect_packet(sock, "dup pubrel", pubrel_packet):
+                sock.send(pubcomp_packet)
+                rc = 0
+            sock.close()
 
 finally:
     broker.terminate()
