@@ -26,13 +26,10 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port)
-    sock.send(publish_packet)
+    mosq_test.do_send_receive(sock, publish_packet, pubrec_packet, "pubrec")
+    mosq_test.do_send_receive(sock, pubrel_packet, pubcomp_packet, "pubcomp")
 
-    if mosq_test.expect_packet(sock, "pubrec", pubrec_packet):
-        sock.send(pubrel_packet)
-
-        if mosq_test.expect_packet(sock, "pubcomp", pubcomp_packet):
-            rc = 0
+    rc = 0
 
     sock.close()
 finally:
