@@ -31,18 +31,15 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, timeout=20, port=port)
     sock.send(publish_packet)
-    sock.send(subscribe_packet)
+    mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
+
+    if mosq_test.expect_packet(sock, "publish", publish_packet):
+        mosq_test.do_send_receive(sock, unsubscribe_packet, unsuback_packet, "unsuback")
+        mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
 
-    if mosq_test.expect_packet(sock, "suback", suback_packet):
         if mosq_test.expect_packet(sock, "publish", publish_packet):
-            sock.send(unsubscribe_packet)
+            rc = 0
 
-            if mosq_test.expect_packet(sock, "unsuback", unsuback_packet):
-                sock.send(subscribe_packet)
-
-                if mosq_test.expect_packet(sock, "suback", suback_packet):
-                    if mosq_test.expect_packet(sock, "publish", publish_packet):
-                        rc = 0
     sock.close()
 finally:
     broker.terminate()
