@@ -21,10 +21,9 @@ puback_packet = mosq_test.gen_puback(mid)
 
 port = mosq_test.get_port()
 sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port)
-sock.send(publish_packet)
+mosq_test.do_send_receive(sock, publish_packet, puback_packet, "puback")
 
-if mosq_test.expect_packet(sock, "puback", puback_packet):
-    rc = 0
+rc = 0
 
 sock.close()
 
