@@ -8,6 +8,8 @@ if cmd_subfolder not in sys.path:
 
 import mosq_test
 
+port = mosq_test.get_port()
+
 rc = 1
 keepalive = 60
 connect_packet = mosq_test.gen_connect("test-helper", keepalive=keepalive)
@@ -19,7 +21,7 @@ pubrec_packet = mosq_test.gen_pubrec(mid)
 pubrel_packet = mosq_test.gen_pubrel(mid)
 pubcomp_packet = mosq_test.gen_pubcomp(mid)
 
-sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=1889, connack_error="helper connack")
+sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port, connack_error="helper connack")
 sock.send(publish_packet)
 
 if mosq_test.expect_packet(sock, "helper pubrec", pubrec_packet):
