@@ -56,16 +56,16 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), use_conf=Tr
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, timeout=20, port=port2)
-    sock.send(subscribe_packet)
+    mosq_test.do_send_receive(sock, subscribe_packet, suback_packet, "suback")
 
-    if mosq_test.expect_packet(sock, "suback", suback_packet):
-        pub = subprocess.Popen(['./c/08-tls-psk-pub.test', str(port1)], env=env, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        if pub.wait():
-            raise ValueError
-        (stdo, stde) = pub.communicate()
+    pub = subprocess.Popen(['./c/08-tls-psk-pub.test', str(port1)], env=env, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    if pub.wait():
+        raise ValueError
+    (stdo, stde) = pub.communicate()
+
+    if mosq_test.expect_packet(sock, "publish", publish_packet):
+        rc = 0
 
-        if mosq_test.expect_packet(sock, "publish", publish_packet):
-            rc = 0
     sock.close()
 finally:
     os.remove(conf_file)
