@@ -8,6 +8,8 @@ if cmd_subfolder not in sys.path:
 
 import mosq_test
 
+port = mosq_test.get_port()
+
 rc = 1
 keepalive = 60
 connect_packet = mosq_test.gen_connect("test-helper", keepalive=keepalive)
@@ -15,7 +17,7 @@ connack_packet = mosq_test.gen_connack(rc=0)
 
 publish_packet = mosq_test.gen_publish("test", qos=0, payload="mount point")
 
-sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=1889, connack_error="helper connack")
+sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port, connack_error="helper connack")
 sock.send(publish_packet)
 rc = 0
 sock.close()
