@@ -22,6 +22,8 @@ if cmd_subfolder not in sys.path:
 
 import mosq_test
 
+port = mosq_test.get_lib_port()
+
 rc = 1
 keepalive = 60
 connect_packet = mosq_test.gen_connect("publish-qos0-test", keepalive=keepalive)
@@ -34,7 +36,7 @@ disconnect_packet = mosq_test.gen_disconnect()
 sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
 sock.settimeout(10)
-sock.bind(('', 1888))
+sock.bind(('', port))
 sock.listen(5)
 
 client_args = sys.argv[1:]
@@ -45,7 +47,7 @@ try:
 except KeyError:
     pp = ''
 env['PYTHONPATH'] = '../../lib/python:'+pp
-client = mosq_test.start_client(filename=sys.argv[1].replace('/', '-'), cmd=client_args, env=env)
+client = mosq_test.start_client(filename=sys.argv[1].replace('/', '-'), cmd=client_args, env=env, port=port)
 
 try:
     (conn, address) = sock.accept()
@@ -62,6 +64,9 @@ try:
 finally:
     client.terminate()
     client.wait()
+    if rc:
+        (stdo, stde) = client.communicate()
+        print(stde)
     sock.close()
 
 exit(rc)
