@@ -14,6 +14,8 @@ if cmd_subfolder not in sys.path:
 
 import mosq_test
 
+port = mosq_test.get_lib_port()
+
 if sys.version < '2.7':
     print("WARNING: SSL not supported on Python 2.6")
     exit(0)
@@ -24,7 +26,7 @@ ssock = ssl.wrap_socket(sock, ca_certs="../ssl/all-ca.crt",
         keyfile="../ssl/server.key", certfile="../ssl/server.crt",
         server_side=True, ssl_version=ssl.PROTOCOL_TLSv1, cert_reqs=ssl.CERT_REQUIRED)
 ssock.settimeout(10)
-ssock.bind(('', 1888))
+ssock.bind(('', port))
 ssock.listen(5)
 
 client_args = sys.argv[1:]
@@ -35,7 +37,7 @@ try:
 except KeyError:
     pp = ''
 env['PYTHONPATH'] = '../../lib/python:'+pp
-client = mosq_test.start_client(filename=sys.argv[1].replace('/', '-'), cmd=client_args, env=env)
+client = mosq_test.start_client(filename=sys.argv[1].replace('/', '-'), cmd=client_args, env=env, port=port)
 
 try:
     (conn, address) = ssock.accept()
