@@ -29,6 +29,8 @@ int main(int argc, char *argv[])
 	int rc;
 	struct mosquitto *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("subscribe-qos1-test", true, NULL);
@@ -36,7 +38,7 @@ int main(int argc, char *argv[])
 	mosquitto_disconnect_callback_set(mosq, on_disconnect);
 	mosquitto_subscribe_callback_set(mosq, on_subscribe);
 
-	rc = mosquitto_connect(mosq, "localhost", 1888, 60);
+	rc = mosquitto_connect(mosq, "localhost", port, 60);
 
 	while(run == -1){
 		mosquitto_loop(mosq, -1, 1);
