@@ -31,16 +31,18 @@ int main(int argc, char *argv[])
 	int rc;
 	struct mosquitto *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("publish-qos0-test", true, NULL);
 	mosquitto_connect_callback_set(mosq, on_connect);
 	mosquitto_publish_callback_set(mosq, on_publish);
 
-	rc = mosquitto_connect(mosq, "localhost", 1888, 60);
+	rc = mosquitto_connect(mosq, "localhost", port, 60);
 
 	while(run == -1){
-		mosquitto_loop(mosq, -1, 1);
+		rc = mosquitto_loop(mosq, -1, 1);
 	}
 
 	mosquitto_lib_cleanup();
