@@ -40,11 +40,13 @@ int main(int argc, char *argv[])
 {
 	struct mosquittopp_test *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosqpp::lib_init();
 
 	mosq = new mosquittopp_test("subscribe-qos1-test");
 
-	mosq->connect("localhost", 1888, 60);
+	mosq->connect("localhost", port, 60);
 
 	while(run == -1){
 		mosq->loop();
